##  Step 2: Create a Tag Group
Create a tag group with the following tags: invest, eliminate, tolerate, and migrate. To learn how to create tag groups, see [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction").
![Tag Group with Tags That Represent the Elements of the Gartner® TIME Framework](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757a5977a44101499d2a524a83a7821_LowRes.png)
Tag Group with Tags That Represent the Elements of the Gartner® TIME Framework
